﻿using System;

using DevExpress.Utils;
using DevExpress.XtraEditors;
using DevExpress.XtraEditors.Mask;
using DevExpress.XtraGrid.Views.Grid;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            this.gridView.InitializeView
            (
                true,                          // Multi Select
                GridMultiSelectMode.RowSelect, // Grid Multi Select Mode
                DrawFocusRectStyle.CellFocus,  // Draw Focus Rect Style
                true,                          // Show Indicator
                true,                          // Show Column Headers
                true,                          // Allow Column Moving
                true,                          // Allow Column Resizing
                true,                          // Allow Filter
                true,                          // Allow Sort
                false,                         // Allow Cell Merge
                EditorShowMode.Default,        // Editor Show Mode
                false                          // Editable
            );

            this.gridView.OptionsBehavior.AutoPopulateColumns = true;

            this.gridView.OptionsView.ShowAutoFilterRow = true;

            this.gridControl.DataSource = new nwindDataSetTableAdapters.ProductsTableAdapter().GetData();

            this.gridView.BestFitColumns();

            this.gridView.ShownEditor += gridView_ShownEditor;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 그리드 뷰 에디터 표시시 처리하기 - gridView_ShownEditor(sender, e)

        /// <summary>
        /// 그리드 뷰 에디터 표시시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void gridView_ShownEditor(object sender, EventArgs e)
        {
            GridView gridView = sender as GridView;

            if(!gridView.IsFilterRow(gridView.FocusedRowHandle))
            {
                return;
            }

            if(gridView.FocusedColumn.FieldName != "UnitPrice")
            {
                return;
            }

            TextEdit textEdit = gridView.ActiveEditor as TextEdit;

            if(textEdit == null)
            {
                return;
            }

            textEdit.Properties.Mask.MaskType = MaskType.Numeric;
        }

        #endregion
    }
}